// Copyright (c) 2015, Will Squire. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

library functional_behaviour_tree.composite.select;

import '../node.dart';
import '../composite.dart';
import 'dart:async';

/// The selector composite processes an array of nodes that it iterates through. Along the way, the selector node will stop its iterating processing of internal nodes if any node returns true. If any node returns true, the selector returns true.
/// The selector will return false if the processing of the internal array reaches the end without any of the nodes returning true; thus failing to make a selection.
Composite select = (Map blackboard, List<Node> nodes) async {
  for(Node node in nodes) {
    if (await node(blackboard))
      return new Future(() => true);
  }
  return new Future(() => false);
};